@@ -8,7 +8,7 @@ from test_autolens.simulators.imaging import instrument_util
 
 # Lets quickly remind ourselves of the image, and the 3.0" circular mask we'll use to mask it.
 imaging = instrument_util.load_test_imaging(
-    data_name="lens_light__source_cuspy", instrument="vro"
+    dataset_name="lens_light__source_cuspy", instrument="vro"
 )
 
 mask = al.Mask2D.circular(
