@@ -116,41 +116,41 @@ def simulator_from_instrument(instrument):
             exposure_time_map=al.Array.full(fill_value=100.0, shape_2d=grid.shape_2d),
             psf=psf,
             background_sky_map=al.Array.full(fill_value=1.0, shape_2d=grid.shape_2d),
-            add_noise=True,
+            add_poisson_noise=True,
         )
     elif instrument in "euclid":
         return al.SimulatorImaging(
             exposure_time_map=al.Array.full(fill_value=2260.0, shape_2d=grid.shape_2d),
             psf=psf,
             background_sky_map=al.Array.full(fill_value=1.0, shape_2d=grid.shape_2d),
-            add_noise=True,
+            add_poisson_noise=True,
         )
     elif instrument in "hst":
         return al.SimulatorImaging(
             exposure_time_map=al.Array.full(fill_value=2000.0, shape_2d=grid.shape_2d),
             psf=psf,
             background_sky_map=al.Array.full(fill_value=1.0, shape_2d=grid.shape_2d),
-            add_noise=True,
+            add_poisson_noise=True,
         )
     elif instrument in "hst_up":
         return al.SimulatorImaging(
             exposure_time_map=al.Array.full(fill_value=2000.0, shape_2d=grid.shape_2d),
             psf=psf,
             background_sky_map=al.Array.full(fill_value=1.0, shape_2d=grid.shape_2d),
-            add_noise=True,
+            add_poisson_noise=True,
         )
     elif instrument in "ao":
         return al.SimulatorImaging(
             exposure_time_map=al.Array.full(fill_value=1000.0, shape_2d=grid.shape_2d),
             psf=psf,
             background_sky_map=al.Array.full(fill_value=1.0, shape_2d=grid.shape_2d),
-            add_noise=True,
+            add_poisson_noise=True,
         )
     else:
         raise ValueError("An invalid instrument was entered - ", instrument)
 
 
-def simulate_imaging_from_instrument(instrument, data_name, galaxies):
+def simulate_imaging_from_instrument(instrument, dataset_name, galaxies):
 
     # Simulate the imaging data, remembering that we use a special image which ensures edge-effects don't
     # degrade our modeling of the telescope optics (e.al. the PSF convolution).
@@ -167,9 +167,7 @@ def simulate_imaging_from_instrument(instrument, data_name, galaxies):
     # Now, lets output this simulated imaging-data to the test_autoarray/simulator folder.
     test_path = "{}/../../".format(os.path.dirname(os.path.realpath(__file__)))
 
-    dataset_path = af.util.create_path(
-        path=test_path, folders=["dataset", "imaging", data_name, instrument]
-    )
+    dataset_path = f"dataset/imaging/{dataset_name}/{instrument}"
 
     imaging.output_to_fits(
         image_path=f"{dataset_path}/image.fits",
@@ -206,13 +204,11 @@ def simulate_imaging_from_instrument(instrument, data_name, galaxies):
     )
 
 
-def load_test_imaging(data_name, instrument, name=None):
+def load_test_imaging(dataset_name, instrument, name=None):
 
     pixel_scales = instrument_util.pixel_scale_from_instrument(instrument=instrument)
 
-    dataset_path = af.util.create_path(
-        path=test_path, folders=["dataset", "imaging", data_name, instrument]
-    )
+    dataset_path = f"dataset/imaging/{dataset_name}/{instrument}"
 
     return al.Imaging.from_fits(
         image_path=f"{dataset_path}/image.fits",
